{ ... } @ args:
let
  gitpkgs = import /home/steveej/src/github/NixOS/nixpkgs {};
  unstablepkgs = import <nixos-unstable> {};

in {
  permittedInsecurePackages = [
    "linux-4.13.16"
  ];

  allowBroken = true;

  chromium = {
    enablePepperFlash = true;
    enablePepperPDF = true;
  };

  firefox = {
    enableGoogleTalkPlugin = true;
    enableAdobeFlash = false;
  };

  pidgin = {
    openssl = true;
    gnutls = true;
  };

  packageOverrides = stablepkgs: rec {

    labshell = (import (unstablepkgs.fetchFromGitHub {
          owner = "htwg-syslab";
          repo = "nix-expressions";
          rev = "89040d81cf6147b1ebaae8eca059f4718400a01a";
          sha256 = "1ci8xbbnj7bdcciq7ibqz8vfhs3ml7k4yx6m8f8whgwrhzk4c8wa";
        }) { labshellExpressionsRemoteRev = "master"; }
      ).labshell;

    busyboxStatic =  stablepkgs.busybox.override {
      enableStatic = true;
      extraConfig = ''
         CONFIG_STATIC y
         CONFIG_INSTALL_APPLET_DONT y
         CONFIG_INSTALL_APPLET_SYMLINKS n
       '';
    };

    dropbearStatic = stablepkgs.dropbear.override {
      enableStatic = true;
    };

    userPackages = with stablepkgs; buildEnv {
      name = "userPackages";
      paths = [
        patchelf
        nix-index

        busyboxStatic 
        #nixUnstable
        #nox
        unetbootin

        androidsdk

        #nixops
        unstablepkgs.ansible2

        picocom
        roxterm
        xorg.xbacklight
        coreutils
        lsof
        pavucontrol
        xscreensaver
        x11_ssh_askpass
        xdotool
        xdg_utils
        xdg-user-dirs
        networkmanagerapplet
        lightdm

        exiv2
        htop

#        gnome3.nautilus
#        gnome3.gvfs
        #(with xfce; 
        #  thunar.override { thunarPlugins = [
        #    thunar_volman
        #    thunar-archive-plugin
        #  ];
        #})
        #xfce.gvfs
        #xfce.xfce4icontheme
        sshfsFuse
        xarchive
        p7zip
        zip
        unzip
        gzip

        python
        python3Packages.ipython
        python3
        jre
        openjdk


        gnupg
        pass
        qtpass
        yubikey-neo-manager
        yubikey-personalization
        yubikey-personalization-gui

        unstablepkgs.chromium
        unstablepkgs.firefox
        seafile-client
        grive2
        dropbox
        zathura
        thunderbird
        unstablepkgs.libreoffice

        pidgin
        hexchat
        gitpkgs.hunspellDicts.en-us
        gitpkgs.hunspellDicts.de-any
        aspellDicts.en
        aspellDicts.de
        unstablepkgs.skype
        #zoom-us

        virtmanager

#        gnome3.dconf
        qemu
        vagrant
        unstablepkgs.rkt
        python27Packages.docker_compose

        remmina
        freerdp
        x2goclient
        samba

        vlc
        audacity
        gitpkgs.spotify

        pdftk
        calibre
        imagemagick
#        gnome3.eog
        unstablepkgs.mendeley

        iptables
        nftables
        iperf
        bind

#        pkgconfig
#        gcc
#        valgrind
#        gdb
#        cgdb
#        man-pages

        unstablepkgs.gimp
        unstablepkgs.inkscape
        unstablepkgs.vscode
        unstablepkgs.atom
        plantuml
        umlet
        graphviz

#        bundler
#        bundix

        nodejs
#        rustc
#        cargo

        travis
        jq

#        pandoc
#        texlive.combined.scheme-medium

        redshift
#        gnome3.pomodoro

        ntfs3g
        ddrescue
        ncdu

        labshell
        xorg.xhost
#        gitpkgs.wtftw
        autorandr
        arandr

#        numix-icon-theme
#        numix-gtk-theme
        gnome3.gnome_themes_standard
        gnome3.adwaita-icon-theme
        lxappearance
        xorg.xcursorthemes

        openssl

        hdparm
        testdisk
        wireshark

        zeroad
      ];
    };
  };
}
